@@ -32,7 +32,6 @@ Data::SUID - Generates thread-safe sequential unique ids
     print $suid->binary                 # 12 bytes of unreadable gibberish
     print $suid                         # 55de233819d51b1a8a67e0ac
 
-
     # Use the hex, dec, uuencode and binary methods as fire-and-forget
     # constructors, if you prefer:
 
@@ -61,7 +60,7 @@ use Readonly;
 use namespace::clean;
 use overload '""' => 'hex';
 
-our $VERSION = '1.000004';
+our $VERSION = '1.000005';
 $VERSION = eval($VERSION);
 
 our @ISA         = qw(Exporter);
@@ -70,37 +69,37 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
 
 =head1 METHODS
 
-=over 2
+=head2 new
 
-=item B<new>
+    $suid = Data::SUID->new();
 
 Generates a new SUID object.
 
-    my $suid = Data::SUID->new();
-
-=back
-
 =cut
 
 
 sub new
 {
     my ($class) = @_;
-    $class = $class || __PACKAGE__;
+    $class = ref($class) || __PACKAGE__;
     my $time = time();
     my $host = &_machine_ident;
     Readonly my $id => sprintf( '%08x%s%04x%s', $time, $host, $$, &_count );
     return bless( \$id, $class );
 }
 
-=over 2
-
-=item B<hex>
+=head2 hex
 
+    $string = $suid->hex();
+    $string = Data::SUID->hex();
+    $string = suid->hex();
+    
 Returns the SUID value as a 24-character hexadecimal string.
 
-The SUID object's stringification operation has been overloaded to give this value, too.
-=back
+    $string = "$suid";
+
+The SUID object's stringification operation has been overloaded to give this
+value, too.
 
 =cut
 
@@ -112,14 +111,14 @@ sub hex
     return $$self;
 }
 
-=over 2
+=head2 dec
 
-=item B<dec>
+    $string = $suid->dec();
+    $string = Data::SUID->dec();
+    $string = suid->dec();
 
 Returns the SUID value as a big integer.
 
-=back
-
 =cut
 
 
@@ -130,14 +129,14 @@ sub dec
     return Math::BigInt->new( '0x' . $$self );
 }
 
-=over 2
+=head2 uuencode
 
-=item B<uuencode>
+    $string = $suid->uuencode();
+    $string = Data::SUID->uuencode();
+    $string = suid->uuencode();
 
 Returns the SUID value as a UUENCODED string.
 
-=back
-
 =cut
 
 
@@ -148,14 +147,14 @@ sub uuencode
     return pack( 'u', pack( 'H*', $$self ) );
 }
 
-=over 2
+=head2 binary
 
-=item B<binary>
+    $binstr = $suid->binary();
+    $binstr = Data::SUID->binary();
+    $binstr = suid->binary();
 
 Returns the SUID value as 12 bytes of binary data.
 
-=back
-
 =cut
 
 
@@ -169,15 +168,11 @@ sub binary
 
 =head1 EXPORTED FUNCTIONS
 
-=over 2
-
-=item B<suid>
-
-Generates a new SUID object.
+=head2 suid
 
     my $suid = suid();
 
-=back
+Generates a new SUID object.
 
 =cut
 
@@ -231,9 +226,10 @@ sub suid
             # assign to count
             $count = "$random";
         }
-
         return $class;
     }
+
+
     sub _count
     {
         &_reset_count unless defined $count;
@@ -248,7 +244,7 @@ sub suid
 
 =head1 REPOSITORY
 
-L<https://github.com/cpanic/Data-SUID>
+L<Data-SUID at GitHub|https://github.com/cpanic/Data-SUID>
 
 =head1 BUG REPORTS
 
@@ -260,7 +256,7 @@ Iain Campbell <cpanic@cpan.org>
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (C) 2012-2015 by Iain Campbell
+Copyright (C) 2014-2015 by Iain Campbell
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
